@@ -79,6 +79,9 @@ u_char texttype;
 /*	   calling routine.					*/
 /*	"pintype" is NORMAL, LOCAL, GLOBAL, or INFO		*/
 /*	"x" and "y" are the label coordinates.			*/
+/*	if "dochange" is FALSE, then this label is being drawn	*/
+/*	   as part of a font or library and should not cause	*/
+/*	   changes count to increment.				*/
 /*								*/
 /* Other properties must be set individually by the calling	*/
 /* 	routine.						*/
@@ -87,7 +90,7 @@ u_char texttype;
 /*--------------------------------------------------------------*/
 
 labelptr new_label(objinstptr destinst, stringpart *strptr, int pintype,
-	int x, int y)
+	int x, int y, u_char dochange)
 {
    labelptr *newlab;
    objectptr destobject;
@@ -108,7 +111,7 @@ labelptr new_label(objinstptr destinst, stringpart *strptr, int pintype,
 
    calcbboxvalues(locdestinst, (genericptr *)newlab);
    updatepagebounds(destobject);
-   incr_changes(destobject);
+   if (dochange != (u_char)0) incr_changes(destobject);
    return *newlab;
 }
 
@@ -129,7 +132,7 @@ labelptr new_simple_label(objinstptr destinst, char *cstr,
    strptr->nextpart = NULL;
    strptr->data.string = cstr;
 
-   return new_label(destinst, strptr, pintype, x, y);
+   return new_label(destinst, strptr, pintype, x, y, (u_char)0);
 }
 
 /*--------------------------------------------------------------*/
@@ -1564,6 +1567,10 @@ void findconstrained(polyptr lastpoly)
 
 	 lflags = nflags = NONE;
 
+	 /* Avoid attempting to manipulate degenerate points. */
+	 if (lpt != NULL && lpt->x == savept->x && lpt->y == savept->y) return;
+	 if (npt != NULL && npt->x == savept->x && npt->y == savept->y) return;
+
          /* two-point polygons (lines) are a degenerate case in RHOMBOID edit mode */
 
          if (areawin->boxedit != MANHATTAN && lastpoly->number <= 2) return;
